"use client";

import { useTransition } from "react";

import { zodResolver } from "@hookform/resolvers/zod";
import { useTranslations } from "next-intl";
import { useForm } from "react-hook-form";

import { Button } from "@/components/ui/button";
import {
	Form,
	FormControl,
	FormField,
	FormItem,
	FormLabel,
	FormMessage,
} from "@/components/ui/form";
import { Input } from "@/components/ui/input";
import PhoneInput from "@/components/ui/phone-input";
import { Textarea } from "@/components/ui/textarea";
import { Locale } from "@/i18n/routing";
import { cn } from "@/lib/utils";

import { useBasicInfo } from "@/servers/data/use-basicinfo";
import { toast } from "sonner";
import { submitContactForm } from "./actions";
import { ContactFormValues, createContactSchema } from "./contact-form";
interface ContactFormClientProps {
	locale: Locale;
}

export function ContactFormClient({ locale }: ContactFormClientProps) {
	const [isPending, startTransition] = useTransition();
	const isRTL = locale === "ar";

	const { texts } = useBasicInfo();
	const t = useTranslations();

	const validationMessages = {
		name: {
			required: t("fullname field is required"),
		},
		email: {
			required: t("email field is required"),
			invalid: t("email is invalid"),
		},
		phone: {
			required: t("phone field is required"),
			invalid: t("phone is invalid"),
		},
		message: {
			required: t("message field is required"),
		},
	};

	const form = useForm<ContactFormValues>({
		resolver: zodResolver(createContactSchema(validationMessages)),
		defaultValues: {
			name: "",
			email: "",
			phone: "",
			message: "",
		},
	});

	function onSubmit(data: ContactFormValues) {
		startTransition(async () => {
			const { success, message } = await submitContactForm({ ...data, phone: `966${data?.phone}` });
			if (success) {
				toast.success(t("Contact request submitted successfully"), {
					style: {
						backgroundColor: "green",
						color: "white",
					},
				});
				form.reset({
					name: "",
					email: "",
					phone: "",
					message: "",
				});
			} else {
				toast.error(t(message));
			}
		});
	}

	return (
		<div className="relative overflow-hidden pt-12 lg:w-1/2 border-[2px]" style={{ backgroundColor: "rgb(246 247 251 / 44%)" }}>
			<div className="relative z-10 mx-auto">
				<div className={cn("px-8 mb-8 text-center", isRTL && "text-right")}>
					<h1 className="text-4xl font-medium text-custom-primary-accent">
						{texts?.contact_us_section_title?.[locale]}
					</h1>
					<p className="my-3 text-[#3B3B3B]">
						{texts?.contact_us_section_description?.[locale]}
					</p>
				</div>

				<div className="px-8 border-t-[1px]" style={{ backgroundColor: "rgba(246, 247, 251, 1)" }}>
					<Form {...form}>
						<form onSubmit={form.handleSubmit(onSubmit)} className="space-y-5 mt-4">
							<FormField
								control={form.control}
								name="name"
								render={({ field }) => (
									<FormItem>
										<FormLabel
											className={cn(
												"text-base after:text-red-500 after:content-['*']",
												isRTL && "text-right"
											)}
										>
											{t("FullName")}
										</FormLabel>
										<FormControl>
											<Input
												className={cn(
													"h-12 rounded-md border-gray-200 bg-white",
													isRTL && "text-right"
												)}
												{...field}
											/>
										</FormControl>
										<FormMessage />
									</FormItem>
								)}
							/>

							<FormField
								control={form.control}
								name="email"
								render={({ field }) => (
									<FormItem>
										<FormLabel
											className={cn(
												"text-base after:text-red-500 after:content-['*']",
												isRTL && "text-right"
											)}
										>
											{t("Email")}
										</FormLabel>
										<FormControl>
											<Input
												type="email"
												className={cn(
													"h-12 rounded-md border-gray-200 bg-white",
													isRTL && "text-right"
												)}
												{...field}
											/>
										</FormControl>
										<FormMessage />
									</FormItem>
								)}
							/>

							<FormField
								control={form.control}
								name="phone"
								render={({ field }) => (
									<FormItem>
										<FormLabel
											className={cn(
												"text-base after:text-red-500 after:content-['*']",
												isRTL && "text-right"
											)}
										>
											{t("Phone")}
										</FormLabel>
										<FormControl>
											<PhoneInput
												id="phone"
												placeholder={t("Phone")}
												className="border-[1px] border-gray-200 bg-white"
												{...field}
											/>
										</FormControl>
										<FormMessage />
									</FormItem>
								)}
							/>
							<FormField
								control={form.control}
								name="message"
								render={({ field }) => (
									<FormItem>
										<FormLabel
											className={cn(
												"text-base after:text-red-500 after:content-['*']",
												isRTL && "text-right"
											)}
										>
											{t("Message")}
										</FormLabel>
										<FormControl>
											<Textarea
												className={cn(
													"min-h-[150px] rounded-md border-gray-200 bg-white",
													isRTL && "text-right"
												)}
												{...field}
											/>
										</FormControl>
										<FormMessage />
									</FormItem>
								)}
							/>

							<Button
								type="submit"
								disabled={isPending}
								className={cn(
									"mt-6 h-12 w-full bg-[#2895C8] text-base font-medium hover:bg-[#2895C8]/90",
									isRTL && "text-right"
								)}
								style={{ marginBottom: "2rem" }}
							>
								{isPending ? t("Sending") : t("Send")}
							</Button>
						</form>
					</Form>
				</div>
			</div>
		</div>
	);
}
